infer_types

Function infer_types 

pub fn infer_types(
    expr: &VerifyExpr,
) -> Result<HashMap<String, VerifyType>, TypeError>
Infer types for all variables in a VerifyExpr.

Returns a map from variable name to inferred type. Returns TypeError if a variable is used with conflicting types.